@@ -139,7 +139,9 @@ class Device:
                 self.longitude = float(location[-1]["lon"] / 1000000)
                 self.speed = location[-1]["speed"]
 
-            self.trip_start_time = self.getvalue(trip[-1], "startDate")
+            self.trip_start_time = self.converttime(
+                self.getvalue(trip[-1], "startDate")
+            )
             self.trip_start_street = self.getvalue(trip[-1], "startRoad")
             self.trip_start_city = self.getvalue(trip[-1], "startCity")
             self.trip_start_city = self.trip_start_city.replace("|m:", " ")
@@ -156,7 +158,9 @@ class Device:
             self.location_name = self.getvalue(trip[-1], "endAlias")
 
             self.trip_start_address = f"{self.trip_start_street}, {self.trip_start_city}, {self.trip_start_country}"
-            self.trip_end_address = f"{self.trip_end_street}, {self.trip_end_city}, {self.trip_end_country}"
+            self.trip_end_address = (
+                f"{self.trip_end_street}, {self.trip_end_city}, {self.trip_end_country}"
+            )
 
     @staticmethod
     def getvalue(data, value):
